/*
 * This file is part of OsmInEdit, released under ISC license (see LICENSE.md)
 *
 * Copyright (c) Adrien Pavie 2019
 * Copyright (c) Daimler AG 2019
 *
 * Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 */

import App from './view/App'
import LocationCard from './view/common/LocationCard';
import POI from './view/common/POI';
import HisTrackCtrl from './view/utils/historyTrackControl';
import MapUtil from './view/utils/MapUtil';
import connectTestTool from './view/utils/connectTestTool';


/*
 * Global variables definition
 */
window.MAP_NAME = "BunnyBlitzMap";
window.EDITOR_URL = window.location.origin + window.location.pathname.substring(0, window.location.pathname.lastIndexOf('/')) + "/";
window.UNUSABLE_ICONS = new Set();


// Create app
let initData = {
	el: 'root', // 渲染地图的 html dom 元素
	id: 'swa3s5ex', // 地图编辑器保存的地图 mapid
	url: "ws://121.42.8.157:19702", // 后端接口，用于查询 mapid 对应的 geojson 数据
	center: { lat: 39.9000, lng: 116.3980 }, // 初始视图中心
	zoom: 18, // 初始缩放级数
	minZoom: 8, // 最小缩放数
	maxZoom: 22, // 最大缩放数
	maxBounds: null, // 最大视图范围
	origin: [39.62413679, 118.16254283], // 自定义坐标系原点
	// forceInit: true, // 重新加载室内地图时，是否强制恢复视图初始状态 默认false
}
let map = new App({ ...initData }) // 创建 map 实例
map.init(); // map 初始化


const BunnyBlitz = {
	MAP: App,
	MapUtil: MapUtil,
	HisTrackControl: HisTrackCtrl,
	LocationCard: LocationCard,
	POI: POI,
	connectTestTool: connectTestTool,
}
export { BunnyBlitz }
